@@ -314,10 +314,11 @@ class RestAPI(object):
 		except KeyError:
 			api_key = None
 		if api_key != None:
-			return r3sponse.success_response(f"Successfully found the uid for the specified user [{uid}].", {"api_key":self.uid_api_keys[uid]})
+			return r3sponse.success_response(f"Successfully found the uid for the specified user [{uid}].", {"api_key":api_key})
 		else:
 			return r3sponse.error_response(f"Failed to find the uid for the specified user [{uid}].")
 	def get_uid_by_key(self, api_key):
+		print(uid+":",api_key,"vs",json.dumps(self.uid_api_keys, indent=4))
 		for uid, _api_key_ in self.uid_api_keys.items():
 			if str(_api_key_) == str(api_key):
 				return r3sponse.success_response("Successfully found the uid for the specified api key.", {"uid":uid})
